@@ -16,7 +16,7 @@ args = parser.parse_args()
 client, path = get_transport_and_path_from_url(args.url)
 
 
-def generate_pack_data(*args, **kwargs):
+def generate_pack_data(have, want, *, ofs_delta=False, progress=None):
     return pack_objects_to_data([])
 
 
