@@ -119,7 +119,7 @@ class CommitGraphCompatTests(CompatTestCase):
 
     def test_commit_graph_generation_and_reading(self):
         """Test that dulwich can read commit graphs generated by C Git."""
-        commits, work_dir = self.create_test_repo_with_history()
+        _commits, work_dir = self.create_test_repo_with_history()
 
         # Generate commit graph with C Git
         run_git_or_fail(["commit-graph", "write", "--reachable"], cwd=work_dir)
@@ -163,7 +163,7 @@ class CommitGraphCompatTests(CompatTestCase):
 
     def test_merge_base_with_commit_graph(self):
         """Test that merge-base calculations work the same with and without commit graph."""
-        commits, work_dir = self.create_test_repo_with_history()
+        _commits, work_dir = self.create_test_repo_with_history()
 
         repo = Repo(self.repo_path)
         self.addCleanup(repo.close)
@@ -240,7 +240,7 @@ class CommitGraphCompatTests(CompatTestCase):
         # Compare with C Git (check if commit1 is ancestor of commit2)
         from .utils import run_git
 
-        returncode, stdout, stderr = run_git(
+        returncode, _stdout, _stderr = run_git(
             ["merge-base", "--is-ancestor", commit1.decode(), commit2.decode()],
             cwd=work_dir,
             capture_stdout=True,
@@ -256,7 +256,7 @@ class CommitGraphCompatTests(CompatTestCase):
 
     def test_generation_numbers_consistency(self):
         """Test that generation numbers are consistent with Git's topology."""
-        commits, work_dir = self.create_test_repo_with_history()
+        _commits, work_dir = self.create_test_repo_with_history()
 
         # Generate commit graph
         run_git_or_fail(["commit-graph", "write", "--reachable"], cwd=work_dir)
@@ -355,7 +355,7 @@ class CommitGraphCompatTests(CompatTestCase):
 
     def test_commit_graph_incremental_update(self):
         """Test that dulwich can read incrementally updated commit graphs."""
-        commits, work_dir = self.create_test_repo_with_history()
+        _commits, work_dir = self.create_test_repo_with_history()
 
         # Create initial commit graph
         run_git_or_fail(["commit-graph", "write", "--reachable"], cwd=work_dir)
